/*******************************************************************************
 * Copyright (c) 2014 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.jubula.toolkit.swt.internal.impl;

import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.jubula.communication.CAP;
import org.eclipse.jubula.toolkit.CapBuilder;
import org.eclipse.jubula.toolkit.enums.ValueSets.*;
import javax.annotation.Generated;

import org.apache.commons.lang.Validate;
import org.apache.commons.lang.StringUtils;

import org.eclipse.jubula.communication.internal.message.MessageCap;
import org.eclipse.jubula.communication.internal.message.MessageParam;
import org.eclipse.jubula.tools.ComponentIdentifier;
import org.eclipse.jubula.tools.internal.constants.TestDataConstants;
import org.eclipse.jubula.tools.internal.objects.IComponentIdentifier;
import org.eclipse.jubula.toolkit.internal.annotations.RealizedType;
import org.eclipse.jubula.toolkit.internal.annotations.TesterClass;

/**
 * Class representing the {@link org.eclipse.swt.widgets.Tree} component from the swt toolkit.
 * @since 4.1
 */
@RealizedType(realizedType="guidancer.concrete.TreeTable")
@TesterClass(testerClass="org.eclipse.jubula.rc.swt.tester.TreeTester")
@Generated(value = "org.eclipse.jubula.toolkit.api.gen.ComponentClassGenerator", 
           date =  "2019-11-26T06:47:23.247Z")
public class TreeTable extends org.eclipse.jubula.toolkit.concrete.internal.impl.TreeTableComponent implements org.eclipse.jubula.toolkit.swt.components.TreeTable {
            public TreeTable(@NonNull ComponentIdentifier componentIdentifier) {
                super(componentIdentifier);
            }
    
    
        /**
         * 
         * @param checked 
         *        Checked
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionOfCheckboxOnSelectedNode(@NonNull Boolean checked,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(checked, "Argument 'checked' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedCheckbox")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(checked)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param checked 
         *        Checked
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionOfCheckboxOnSelectedNode(@NonNull Boolean checked
        ) throws IllegalArgumentException {
            Validate.notNull(checked, "Argument 'checked' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedCheckbox")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(checked)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param textpath 
         *        the textpath to use
         * @param operator 
         *        the operator used for comparison
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * 
         */
        @NonNull public CAP toggleCheckboxOnNodeByTextpath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String textpath,@NonNull Operator operator
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(textpath, "Argument 'textpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcToggleCheckbox")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(textpath)
                        .addParameter(operator.rcValue())
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param indexpath 
         *        the 1-based indexpath e.g. "1/2/1"
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * 
         */
        @NonNull public CAP toggleCheckboxOnNodeByIndexpath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String indexpath
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(indexpath, "Argument 'indexpath' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcToggleCheckboxByIndices")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(indexpath)
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param textpath 
         *        the textpath to use
         * @param operator 
         *        the operator used for comparison
         * @param checked 
         *        Checked
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionOfCheckboxByTextpath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String textpath,@NonNull Operator operator,@NonNull Boolean checked,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(textpath, "Argument 'textpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(checked, "Argument 'checked' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyCheckbox")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(textpath)
                        .addParameter(operator.rcValue())
                        .addParameter(checked)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param textpath 
         *        the textpath to use
         * @param operator 
         *        the operator used for comparison
         * @param checked 
         *        Checked
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionOfCheckboxByTextpath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String textpath,@NonNull Operator operator,@NonNull Boolean checked
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(textpath, "Argument 'textpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(checked, "Argument 'checked' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyCheckbox")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(textpath)
                        .addParameter(operator.rcValue())
                        .addParameter(checked)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param indexpath 
         *        the 1-based indexpath e.g. "1/2/1"
         * @param checked 
         *        Checked
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionOfCheckboxByIndexpath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String indexpath,@NonNull Boolean checked,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(indexpath, "Argument 'indexpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(checked, "Argument 'checked' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyCheckboxByIndices")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(indexpath)
                        .addParameter(checked)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param indexpath 
         *        the 1-based indexpath e.g. "1/2/1"
         * @param checked 
         *        Checked
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionOfCheckboxByIndexpath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String indexpath,@NonNull Boolean checked
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(indexpath, "Argument 'indexpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(checked, "Argument 'checked' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyCheckboxByIndices")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(indexpath)
                        .addParameter(checked)
                        .addParameter(0)
                        .build();
        }
        
} 